
%Example of an input file for the two-fluids version of VolFlow
%Cold avalanche + tsunami
%K. Kelfoun, 2021 - UCA / LMV - lmv.uca.fr/kelfoun-karim

%z  = topography
%h  = avalanche thickness
%hw = water depth

%Reads the topography - you can use a mat file or write the line to read a
%geotif-file, a surfer-file, an ascii-file...
load('z.mat')
[nrow, ncol] = size(z);

%Uses an image in black and white to define the initial thickness of the avalanche
%the size of h must equal the size of z
h = (255-double(imread('thicknessVF.tif')))/255*50; %maximal thickness = 20 m

%space step in meters
dx_horiz = 500;
dy_horiz = dx_horiz;

%axis x et y in km - this is done for the visualization only. 
%x and y are not used by VolcFlow
x = [1:ncol]*dx_horiz/1000;
y = [1:nrow]*dy_horiz/1000;

%Calculation parameters -------------------------------
dt=0.5;              %time step
tstep_adjust = 0;    %time step fixed  do not change for tsunamis
dtplot = 10;         %time step for the figures
tmax = 1000;         %max calculation time
g=9.81;

%Rheology -------------------------------
delta_int = 0/180*pi;
delta_bed = 0/180*pi; 
cohesion  = 50000; %cohesion or yield strength (Pa)
viscosity = [0 1.137*10^-3]; %1st value = avalanche, 2nd = water
coef_u2   = [0.001 0.001];       
rho       = [2500 1025]; %densities: 2500 kg/m3 for the avalanche, 1025 kg/m3 for the water

%Use the forces of Tinti et al., 2006:
%Tinti, S., G. Pagnoni, and F. Zaniboni (2006), The landslides and tsunamis of the 30th of December 2002
%in Stromboli analysed through numerical simulations. Bull. Volcanol., 68, 462 479. )
Tinti = 1; %1 = used, 0 = not used
Cf = 0.01; Cs = 0.01;

Lb = 50;   %to improve the open-boundary conditions
%Lb is the number of cells of the boundary where the parallel component of the movement progressively decreases

L3Dinteract = 0; %horizontal distance (in m) of influence of a local avalanche variation on the water
%used for pseudo-3D calculation. 0 = not 3D calculation = faster
%see https://agupubs.onlinelibrary.wiley.com/doi/full/10.1029/2009JF001381

%Function for 3D visualization of the results -------------------------------
representation = 'repr_whitesea';

%data saved and avi-file of the simulation
f_data = 'test.dat';
f_avi = 'test.avi';
%saved_var = {'h', 'umx',  'umy', 'hw'}; %default option of variable saved

%Source and boundary conditions -------------------------------------
Hmax=0; %will record the max amplitude of the waves
source = 'Hmax=max(Hmax, hw-hwini+h-hini);'; %no source but the function is used to record the max wave height 
bound_cond = '';


% do not modify below ==================================
indCx = [];
indCy = [];

%change z at the boundaries for stabler boundary conditions
z(:,1)=z(:,3);
z(:,end)=z(:,end-2);
z(1,:)=z(3,:);
z(end,:)=z(end-2,:);

z(:,2)=z(:,3);
z(:,end-1)=z(:,end-2);
z(2,:)=z(3,:);
z(end-1,:)=z(end-2,:);

%Inital water depth
hw =  0 - z - h;
hw(hw<0)=0;
t=0;

%change z at the shores for a better stability
%= equilibrium weight stress / thickness gradient stress at the shore
kk=hw*0;
kk(hw>0)=1;
kk=kk+del2(kk);
z(kk>0 & z>0)=0;

hwini = hw;
hini = h;
zini=z;
hgini=h;
doubleUpwind = 1;

%initial velocities
u_xx = z(1:nrow, 1:ncol-1)*0;
u_xy = z(1:nrow, 1:ncol-1)*0;
u_yy = z(1:nrow-1, 1:ncol)*0;
u_yx = z(1:nrow-1, 1:ncol)*0;

uw_xx = z(1:nrow, 1:ncol-1)*0;
uw_xy = z(1:nrow, 1:ncol-1)*0;
uw_yy = z(1:nrow-1, 1:ncol)*0;
uw_yx = z(1:nrow-1, 1:ncol)*0;




