%Example of an input file for the two-fluids version of VolFlow
%Cold avalanche + tsunami
%K. Kelfoun, 2021 - UCA / LMV - lmv.uca.fr/kelfoun-karim

cla

max_h = 20; % max amplitude, in 50 m
imagesc(x,y,h, [-max_h max_h]); %just to help Matlab to make the correct range
                          %must be compatible with ligne 16-18
hold on

%Sea color
    ech=imread('colorscale4b.jpg');
    ma_coul = double([ech(1,:,1)' ech(1,:,2)' ech(1,:,3)'])/255;

    hh2=(hw+h-hwini-hgini)*100/max_h+100;
    hh2(hh2>200)=200;
    k1=ind2rgb(round(hh2),ma_coul);

    %remove the island
    kk=k1(:,:,1); kk(z>0)=0; k1(:,:,1)=kk;
    kk=k1(:,:,2); kk(z>0)=0; k1(:,:,2)=kk;
    kk=k1(:,:,3); kk(z>0)=0; k1(:,:,3)=kk;

%Topo color
    ech=imread('mygray.jpg');
    mygray = double([ech(1,:,1)' ech(1,:,2)' ech(1,:,3)'])/255;
    k2=ind2rgb(round(gradient(z+h, dx_horiz)*200+120),mygray);
    kk=k2(:,:,1); kk(hw>0.01)=0; k2(:,:,1)=kk;
    kk=k2(:,:,2); kk(hw>0.01)=0; k2(:,:,2)=kk;
    kk=k2(:,:,3); kk(hw>0.01)=0; k2(:,:,3)=kk;
    
    
%Sea + topo
    k3 = k1+k2;

%Debris avalanche
    ech=imread('colorscale5.jpg');
    ma_coul2 = double([ech(1,:,1)' ech(1,:,2)' ech(1,:,3)'])/255;
    k4=ind2rgb(round(h*5),ma_coul2);

%Add the avalanche
    kk=k3(:,:,1); jj=k4(:,:,1); kk(h>0.01)=jj(h>0.01); k3(:,:,1)=kk;
    kk=k3(:,:,2); jj=k4(:,:,2); kk(h>0.01)=jj(h>0.01); k3(:,:,2)=kk;
    kk=k3(:,:,3); jj=k4(:,:,3); kk(h>0.01)=jj(h>0.01); k3(:,:,3)=kk;
    

image(x,y,k3)

colormap(ma_coul)
p = colorbar;

axis equal tight
set(gca, 'ydir', 'reverse');
set(gcf, 'color', 'w')

texto = sprintf('time: %5.0f s.', t);
text(20, 20, texto, 'fontsize', 16, 'fontweight', 'b')

%The data can be saved in a dat-file (read with VFreader)
%but you can also add the method you want to save what you want
if t/100 == round(t/100)  %to save data each 100 s
    name_file = sprintf('save_%d.mat', t);
    save(name_file, 'hw', 'h'); %add all the variables you want
    name_file = sprintf('save_%d.tif', t);
    im = getframe(gcf);
    im=frame2im(im);
    imwrite(im, name_file)
end



